@@ -1,2 +1,7 @@
 from pubweb.clients.api import ApiClient
 from pubweb.clients.s3 import S3Client
+
+__all__ = [
+    'ApiClient',
+    'S3Client'
+]
